# kauldron

[![Unittests](https://github.com/google-research/kauldron/actions/workflows/pytest_and_autopublish.yml/badge.svg)](https://github.com/google-research/kauldron/actions/workflows/pytest_and_autopublish.yml)
[![PyPI version](https://badge.fury.io/py/kauldron.svg)](https://badge.fury.io/py/kauldron)
[![Documentation Status](https://readthedocs.org/projects/kauldron/badge/?version=latest)](https://kauldron.readthedocs.io/en/latest/?badge=latest)

*This is not an officially supported Google product.*
